#!/bin/sh

if grep -q QEMU /proc/cpuinfo || dmesg | grep -q 'Manufacturer: QEMU' ; then
	export WITHOUT_SWAP=yes
	touch /tmp/without_swap
fi

for disk in $(list-harddrives | grep -v fd0 | awk '{printf $1 " "}'); do
	dd if=/dev/zero of=/dev/$disk bs=512 count=32
	parted -s ${disk} mklabel gpt;
done

SWSIZE=$(grep MemTotal /proc/meminfo  | awk '{print int($2/1024)+1}')
if [ ${SWSIZE} -gt 2048 ]; then
	SWSIZE=2048
fi

if [ `cat /proc/scsi/scsi | grep -wc ATA` -eq 2 ]; then
	set $(list-harddrives | grep -v fd0 | awk '{printf $1 " "}')
	HD1=$1
	HD2=$2
	if [ -b /dev/${HD2} ]; then
		SIZE1=$(fdisk -l "/dev/${HD1}"  2>/dev/null  | grep Disk | grep dev |  sed 's/://'|awk '{print $5}')
		SIZE2=$(fdisk -l "/dev/${HD2}"  2>/dev/null  | grep Disk | grep dev |  sed 's/://'|awk '{print $5}')
		if [ -n "${SIZE1}" ] && [ -n "${SIZE2}" ] && [ "${SIZE1}" = "${SIZE2}" ]; then
			USE_MIRROR=yes
		fi
	fi
fi

set $(list-harddrives | grep -v fd0 | grep -v md[0-9] | awk '{printf $1 " "}')
HD1=$1
HD2=$2


if [ -d /sys/firmware/efi ]; then
  efibootmgr -v | grep BootCurrent | cut -d' ' -f2 > /tmp/efi_booted
	if [ -n "${USE_MIRROR}" ]; then
      echo "part /boot/efi --fstype vfat --size=200 --ondisk=${HD1}" >> /tmp/part-include
      echo "part /boot/efi --fstype vfat --size=200 --ondisk=${HD2}" >> /tmp/part-include
	else
      echo "part /boot/efi --fstype vfat --size=200 --ondisk=${HD1}" >> /tmp/part-include
	fi
fi

if [ "($PART)" != "" ] && [ "($PART)" != "()" ] && [ "($PART)" = "vmmgr-raw" ]; then
	if [ -n "${USE_MIRROR}" ]; then
	  if [ ! -d /sys/firmware/efi ]; then
      if [ ${SIZE1} -gt 2254857830400 ]; then
        # bios boot partition necessary
        echo "part biosboot --fstype=biosboot --size=1 --ondisk=${HD1}" >> /tmp/part-include
        echo "part biosboot --fstype=biosboot --size=1 --ondisk=${HD2}" >> /tmp/part-include
      fi
	  fi
		cat >> /tmp/part-include << EOF
part raid.01 --size=1024 --asprimary --ondisk=${HD1}
part raid.02 --size=1024 --asprimary --ondisk=${HD2}
part raid.11 --size=35840 --asprimary --ondisk=${HD1}
part raid.12 --size=35840 --asprimary --ondisk=${HD2}
part raid.21 --grow --asprimary --ondisk=${HD1}
part raid.22 --grow --asprimary --ondisk=${HD2}
raid swap --fstype=swap --level=RAID1 --device=md0 raid.01 raid.02
raid / --fstyp=xfs --level=RAID1 --device=md1 raid.11 raid.12
raid /vm --fstype=xfs --level=RAID1 --device=md2 raid.21 raid.22
EOF
	else
	  if [ ! -d /sys/firmware/efi ]; then
      if [ ${SIZE1} -gt 2254857830400 ]; then
        # bios boot partition necessary
        echo "part biosboot --fstype=biosboot --size=1 --ondisk=${HD1}" >> /tmp/part-include
      fi
	  fi
		cat >> /tmp/part-include << EOF
bootloader --location=mbr --driveorder=${HD1}
part swap --fstype=swap --size=16384 --asprimary --ondisk=${HD1}
part / --fstype=ext4 --size=35840 --asprimary --ondisk=${HD1}
part /vm --fstype=xfs --size=35840 --grow --asprimary --ondisk=${HD1}
EOF
	fi
else

	if [ -z "${WITHOUT_SWAP}" ] && [ -n "${USE_MIRROR}" ]; then
	# get disk size in GB
	#  DISKSIZE=`parted -sm /dev/$DEV unit GB print | grep -e "$DEV" | cut -d: -f2 | sed -e 's/GB$//'`
	  if [ ! -d /sys/firmware/efi ]; then
      if [ ${SIZE1} -gt 2254857830400 ]; then
        # bios boot partition necessary
        echo "part biosboot --fstype=biosboot --size=1 --ondisk=${HD1}" >> /tmp/part-include
        echo "part biosboot --fstype=biosboot --size=1 --ondisk=${HD2}" >> /tmp/part-include
      fi
	  fi
      cat >> /tmp/part-include << EOF
part raid.11 --size=512 --asprimary --ondisk=${HD1}
part raid.12 --size=${SWSIZE} --asprimary --ondisk=${HD1}
part raid.13 --size=1 --grow --asprimary --ondisk=${HD1}
part raid.21 --size=512 --asprimary --ondisk=${HD2}
part raid.22 --size=${SWSIZE} --asprimary --ondisk=${HD2}
part raid.23 --size=1 --grow --asprimary --ondisk=${HD2}
raid /boot --fstype ext4 --level=RAID1 --device=md0 raid.11 raid.21
raid swap --fstype swap --level=RAID1 --device=md1 raid.12 raid.22
raid / --fstype xfs --level=RAID1 --device=md2 raid.13 raid.23
EOF
	  else
	  # get disk size in GB
	  DISKSIZE=`parted -sm /dev/${HD1} unit GB print 2>/dev/null | grep -e "${HD1}" | cut -d: -f2 | sed -e 's/GB$//'`
	  if [ ! -d /sys/firmware/efi ]; then
      if [ ${DISKSIZE} -gt 2000 ]; then
        # bios boot partition necessary
        echo "part biosboot --fstype=biosboot --size=1 --ondisk=${HD1}" >> /tmp/part-include
      fi
	  fi
	  cat >> /tmp/part-include << EOF
part /boot --fstype ext4 --size=512 --asprimary --ondisk=${HD1}
part swap --size=${SWSIZE} --asprimary --ondisk=${HD1}
part / --fstype xfs --size=1 --grow --asprimary --ondisk=${HD1}
EOF
		if [ -n "${WITHOUT_SWAP}" ]; then
			sed -i -r '/swap/d' /tmp/part-include
		fi
	fi
fi


